==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_he.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="he" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation>אינטרנט</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>צ׳אט</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>מוזיקה</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>וידאו</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>גרפיקה</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>משרדי</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>קריאה</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>פיתוח</translation>
    </message>
    <message>
        <source>System</source>
        <translation>מערכת</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>משחקים</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>אחר</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>אימות</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>הסר</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>פתיחה</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation>אינטרנט</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>צ׳אט</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>מוזיקה</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>וידאו</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>גרפיקה</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>משחק</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>משרדי</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>קריאה</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>פיתוח</translation>
    </message>
    <message>
        <source>System</source>
        <translation>מערכת</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>אחרים</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>מחשב</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>מוזיקה</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>הורדות</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>נעילה</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>התנתקות</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>כיבוי</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>חזרה</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>מחשב</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>מוזיקה</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>כיבוי</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>נעילה</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>התנתקות</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>חזרה</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>הורדות</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>מחשב</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>מוזיקה</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>הורדות</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ידני</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation>צריכת חשמל</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation>חזרה</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>חפש</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>אימות</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-launcher_5.4.5.orig.tar.xz: dde-launcher-5.4.5/translations/dde-launcher_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>אינטרנט</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>צ׳אט</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>מוזיקה</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>וידאו</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>גרפיקה</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>משרדי</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>קריאה</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>פיתוח</translation>
    </message>
    <message>
        <source>System</source>
        <translation>מערכת</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>משחקים</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>אחר</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>אימות</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>הסר</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation>פתיחה</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>אינטרנט</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>צ׳אט</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>מוזיקה</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>וידאו</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>גרפיקה</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>משחק</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>משרדי</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>קריאה</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>פיתוח</translation>
    </message>
    <message>
        <source>System</source>
        <translation>מערכת</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>אחרים</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation type="vanished">מחשב</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">מוזיקה</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="vanished">הורדות</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="vanished">נעילה</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="vanished">התנתקות</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="vanished">השהיה</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="vanished">כיבוי</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">חזרה</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>מחשב</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>מוזיקה</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>כיבוי</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>נעילה</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>התנתקות</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>חזרה</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>הורדות</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation type="vanished">מחשב</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">מוזיקה</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="vanished">הורדות</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="vanished">ידני</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">הגדרות</translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">צריכת חשמל</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation>חזרה</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>חפש</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>אימות</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
